#!/usr/bin/env python3
# -*- coding:utf-8 -*-

from distutils.core import setup

setup(
    name="printListModuleSandeepBabu",
    version="1.0.0",
    description="An API to print list recursively",
    author="Sandeep",
    author_email="sandeep.babu@ignitarium.com",
    py_modules=["printListModule"],
)
